@@ -10,11 +10,14 @@ from .daemonset import DaemonSet
 from .deployment import Deployment
 from .endpoints import Endpoints
 from .event import Event
+from .ingress import Ingress
 from .namespace import Namespace
 from .node import Node
 from .persistentvolumeclaim import PersistentVolumeClaim
 from .pod import Pod
+from .replicaset import ReplicaSet
 from .rolebinding import RoleBinding
 from .secret import Secret
 from .service import Service
+from .serviceaccount import ServiceAccount
 from .statefulset import StatefulSet
