@@ -4,7 +4,7 @@ import logging
 
 from kubernetes import client
 
-log = logging.getLogger('kubetest')
+log = logging.getLogger("kubetest")
 
 
 class Event:
@@ -19,14 +19,14 @@ class Event:
     Event object to make Event-based interactions easier
 
     .. _Event:
-        https://kubernetes.io/docs/reference/generated/kubernetes-api/v1.17/#event-v1-core
+        https://kubernetes.io/docs/reference/generated/kubernetes-api/v1.18/#event-v1-core
     """
 
     obj_type = client.V1Event
 
     api_clients = {
-        'preferred': client.CoreV1Api,
-        'v1': client.CoreV1Api,
+        "preferred": client.CoreV1Api,
+        "v1": client.CoreV1Api,
     }
 
     def __init__(self, api_object) -> None:
