@@ -8,6 +8,7 @@ the state of the cluster.
 import logging
 import os
 import warnings
+from typing import Optional
 
 import kubernetes
 import pytest
@@ -17,9 +18,9 @@ from kubetest import errors, markers
 from kubetest.client import TestClient
 from kubetest.manager import KubetestManager
 
-GOOGLE_APPLICATION_CREDENTIALS = 'GOOGLE_APPLICATION_CREDENTIALS'
+GOOGLE_APPLICATION_CREDENTIALS = "GOOGLE_APPLICATION_CREDENTIALS"
 
-log = logging.getLogger('kubetest')
+log = logging.getLogger("kubetest")
 
 # A global instance of the KubetestManager. This will be used by various
 # pytest hooks and fixtures in order to create and manage the TestClient
@@ -31,6 +32,7 @@ manager = KubetestManager()
 
 # ********** pytest hooks **********
 
+
 def pytest_addoption(parser):
     """Add options to pytest to configure kubetest.
 
@@ -38,36 +40,36 @@ def pytest_addoption(parser):
         https://docs.pytest.org/en/latest/reference.html#_pytest.hookspec.pytest_addoption
     """
 
-    group = parser.getgroup('kubetest', 'kubernetes integration test support')
+    group = parser.getgroup("kubetest", "kubernetes integration test support")
     group.addoption(
-        '--kube-config',
-        action='store',
-        metavar='path',
-        default=None,
+        "--kube-config",
+        action="store",
+        metavar="path",
+        default=os.getenv("KUBECONFIG"),
         help=(
-            'the kubernetes config for kubetest; this is required for '
-            'resources to be installed on the cluster'
-        )
+            "the kubernetes config for kubetest; this is required for "
+            "resources to be installed on the cluster"
+        ),
     )
     group.addoption(
-        '--kube-context',
-        action='store',
-        metavar='context',
+        "--kube-context",
+        action="store",
+        metavar="context",
         default=None,
-        help='the name of the kubernetes config context to use',
+        help="the name of the kubernetes config context to use",
     )
     group.addoption(
-        '--kube-disable',
-        action='store_true',
+        "--kube-disable",
+        action="store_true",
         default=False,
-        help='[DEPRECATED] disable automatic configuration with the kubeconfig file'
+        help="[DEPRECATED] disable automatic configuration with the kubeconfig file",
     )
 
     group.addoption(
-        '--in-cluster',
-        action='store_true',
+        "--in-cluster",
+        action="store_true",
         default=False,
-        help='use the kubernetes in-cluster config',
+        help="use the kubernetes in-cluster config",
     )
 
     # FIXME (etd) - this was an attempt to fix occasional permissions errors
@@ -82,26 +84,27 @@ def pytest_addoption(parser):
     # )
 
     group.addoption(
-        '--kube-log-level',
-        action='store',
-        default='warning',
-        help='log level for the kubetest logger'
+        "--kube-log-level",
+        action="store",
+        default="warning",
+        help="log level for the kubetest logger",
     )
 
     group.addoption(
-        '--kube-error-log-lines',
-        action='store',
+        "--kube-error-log-lines",
+        action="store",
         default=50,
-        help='set the number of lines to tail from container logs on error. '
-             'to show all lines, set this to -1.'
+        type=int,
+        help="set the number of lines to tail from container logs on error. "
+        "to show all lines, set this to -1.",
     )
 
     group.addoption(
-        '--suppress-insecure-request',
-        action='store',
+        "--suppress-insecure-request",
+        action="store",
         default=False,
-        help='suppress the urllib3 InsecureRequestWarning. This is useful if testing '
-             'against a cluster without HTTPS set up.'
+        help="suppress the urllib3 InsecureRequestWarning. This is useful if testing "
+        "against a cluster without HTTPS set up.",
     )
 
 
@@ -111,20 +114,20 @@ def pytest_report_header(config):
     See Also:
         https://docs.pytest.org/en/latest/reference.html#_pytest.hookspec.pytest_report_header
     """
-    config_file = config.getoption('kube_config')
+    config_file = config.getoption("kube_config")
     if config_file is None:
-        config_file = 'default'
+        config_file = "default"
 
-    if config.getoption('in_cluster'):
-        config_file = 'in-cluster'
+    if config.getoption("in_cluster"):
+        config_file = "in-cluster"
 
-    context = config.getoption('kube_context')
+    context = config.getoption("kube_context")
     if context is None:
-        context = 'current context'
+        context = "current context"
 
     return [
-        f'kubetest config file: {config_file}',
-        f'kubetest context: {context}',
+        f"kubetest config file: {config_file}",
+        f"kubetest context: {context}",
     ]
 
 
@@ -140,7 +143,7 @@ def pytest_configure(config):
     markers.register(config)
 
     # Disable warnings, if configured to do so.
-    if config.getoption('suppress_insecure_request'):
+    if config.getoption("suppress_insecure_request"):
         urllib3.disable_warnings(urllib3.exceptions.InsecureRequestWarning)
 
 
@@ -163,17 +166,17 @@ def pytest_sessionstart(session):
         https://docs.pytest.org/en/latest/reference.html#_pytest.hookspec.pytest_sessionstart
     """
     # Setup the kubetest logger
-    log_level = session.config.getoption('kube_log_level')
+    log_level = session.config.getoption("kube_log_level")
     level = logging._nameToLevel.get(log_level.upper(), logging.WARNING)
-    logger = logging.getLogger('kubetest')
+    logger = logging.getLogger("kubetest")
     logger.setLevel(level)
 
     # Check for configuration deprecations
-    if session.config.getoption('kube_disable'):
+    if session.config.getoption("kube_disable"):
         warnings.warn(
-            '--kube-disable flag is deprecated (v0.2.0) and is no longer functional. '
-            'To disable the plugin for a project, see: '
-            'https://docs.pytest.org/en/latest/plugins.html',
+            "--kube-disable flag is deprecated (v0.2.0) and is no longer functional. "
+            "To disable the plugin for a project, see: "
+            "https://docs.pytest.org/en/latest/plugins.html",
         )
 
     # # Configure kubetest with the kubernetes config, if not disabled.
@@ -229,9 +232,9 @@ def pytest_runtest_setup(item):
 
     namespace_create = True
     namespace_name = None
-    for mark in item.iter_markers(name='namespace'):
-        namespace_create = mark.kwargs.get('create', True)
-        namespace_name = mark.kwargs.get('name', None)
+    for mark in item.iter_markers(name="namespace"):
+        namespace_create = mark.kwargs.get("create", True)
+        namespace_name = mark.kwargs.get("name", None)
 
     # Register a new test case with the manager and setup the test case state.
     test_case = manager.new_test(
@@ -291,12 +294,14 @@ def pytest_runtest_teardown(item):
     # override, there will be more than one fixture associated with the 'kubeconfig'
     # name. In such case, we should assume that a fixture was used to load the config
     # and allow test cleanup to proceed.
-    _, _, fixtures = item.session._fixturemanager.getfixtureclosure(['kubeconfig'], item)
+    _, _, fixtures = item.session._fixturemanager.getfixtureclosure(
+        ["kubeconfig"], item
+    )
 
     if (
-        item.config.getoption('kube_config') or
-        len(fixtures.get('kubeconfig', [])) > 1 or
-        item.config.getoption('in_cluster')
+        item.config.getoption("kube_config")
+        or len(fixtures.get("kubeconfig", [])) > 1
+        or item.config.getoption("in_cluster")
     ):
         manager.teardown(item.nodeid)
 
@@ -311,24 +316,22 @@ def pytest_runtest_makereport(item, call):
     """
 
     # skip for tests without fixtures (eg: doctests)
-    if not hasattr(item, 'fixturenames'):
+    if not hasattr(item, "fixturenames"):
         return
 
-    if 'kube' in item.fixturenames and call.when == 'call':
-        if call.excinfo is not None and call.excinfo.typename != 'Skipped':
-            tail_lines = item.config.getoption('kube_error_log_lines')
+    if "kube" in item.fixturenames and call.when == "call":
+        if call.excinfo is not None and call.excinfo.typename != "Skipped":
+            tail_lines = item.config.getoption("kube_error_log_lines")
             if tail_lines != 0:
                 test_case = manager.get_test(item.nodeid)
                 if test_case:
-                    logs = test_case.yield_container_logs(
-                        tail_lines=tail_lines
-                    )
+                    logs = test_case.yield_container_logs(tail_lines=tail_lines)
                     for container_log in logs:
                         # Add a report section to the test output
                         item.add_report_section(
                             when=call.when,
-                            key='kubernetes container logs',
-                            content=container_log
+                            key="kubernetes container logs",
+                            content=container_log,
                         )
 
 
@@ -346,9 +349,9 @@ def pytest_keyboard_interrupt():
             name = ns.metadata.name
             status = ns.status
             if (
-                    name.startswith('kubetest-') and
-                    status is not None and
-                    status.phase.lower() == 'active'
+                name.startswith("kubetest-")
+                and status is not None
+                and status.phase.lower() == "active"
             ):
                 print(f'keyboard interrupt: cleaning up namespace "{name}"')
                 kubernetes.client.CoreV1Api().delete_namespace(
@@ -360,7 +363,7 @@ def pytest_keyboard_interrupt():
         for crb in crbs.items:
             # if the cluster role binding has a 'kubetest:' prefix, remove it.
             name = crb.metadata.name
-            if name.startswith('kubetest:'):
+            if name.startswith("kubetest:"):
                 print(f'keyboard interrupt: cleaning up clusterrolebinding "{crb}"')
                 kubernetes.client.RbacAuthorizationV1Api().delete_cluster_role_binding(
                     body=kubernetes.client.V1DeleteOptions(),
@@ -368,8 +371,8 @@ def pytest_keyboard_interrupt():
                 )
     except Exception as e:
         log.error(
-            'Failed to clean up kubetest artifacts from cluster on keyboard interrupt. '
-            'You may need to manually remove items from your cluster. Check for '
+            "Failed to clean up kubetest artifacts from cluster on keyboard interrupt. "
+            "You may need to manually remove items from your cluster. Check for "
             'namespaces with the "kubetest-" prefix and cluster role bindings with '
             f'the "kubetest:" prefix. ({e})'
         )
@@ -377,6 +380,7 @@ def pytest_keyboard_interrupt():
 
 # ********** pytest fixtures **********
 
+
 class ClusterInfo:
     """Information about the cluster the kubetest is being run on.
 
@@ -391,9 +395,9 @@ class ClusterInfo:
     """
 
     def __init__(self, current, config):
-        self.cluster = current['context']['cluster']
-        self.user = current['context']['user']
-        self.context = current['name']
+        self.cluster = current["context"]["cluster"]
+        self.user = current["context"]["user"]
+        self.context = current["name"]
         self.host = config.host
         self.verify_ssl = config.verify_ssl
 
@@ -410,9 +414,11 @@ def clusterinfo(kubeconfig) -> ClusterInfo:
 
     # Get the current context.
     _, current = kubernetes.config.list_kube_config_contexts(
-        os.path.expandvars(os.path.expanduser(
-            kubeconfig,
-        ))
+        os.path.expandvars(
+            os.path.expanduser(
+                kubeconfig,
+            )
+        )
     )
 
     return ClusterInfo(
@@ -422,39 +428,50 @@ def clusterinfo(kubeconfig) -> ClusterInfo:
 
 
 @pytest.fixture
-def kubeconfig(request) -> str:
+def kubeconfig(request) -> Optional[str]:
     """Return the name of the configured kube config file loaded for the tests."""
 
-    config_file = request.session.config.getoption('kube_config')
+    config_file = request.session.config.getoption("kube_config")
     return config_file
 
 
+@pytest.fixture
+def kubecontext(request) -> Optional[str]:
+    """Return the context in the kubeconfig to use for the tests.
+
+    When None, use the current context as set in the kubeconfig.
+    """
+
+    context = request.session.config.getoption("kube_context")
+    return context
+
+
 @pytest.fixture()
-def kube(kubeconfig, request) -> TestClient:
+def kube(kubeconfig, kubecontext, request) -> TestClient:
     """Return a client for managing a Kubernetes cluster for testing."""
 
-    if request.session.config.getoption('in_cluster'):
+    if request.session.config.getoption("in_cluster"):
         kubernetes.config.load_incluster_config()
     else:
         if kubeconfig:
             kubernetes.config.load_kube_config(
                 config_file=os.path.expandvars(os.path.expanduser(kubeconfig)),
-                context=request.session.config.getoption('kube_context'),
+                context=kubecontext,
             )
         else:
             log.error(
-                'unable to interact with cluster: kube fixture used without kube config '
-                'set. the config may be set with the --kube-config or --in-cluster flags '
-                'or by defining a custom kubeconfig fixture.'
+                "unable to interact with cluster: kube fixture used without kube config "
+                "set. the config may be set with the flags --kube-config or --in-cluster or by"
+                "an env var KUBECONFIG or custom kubeconfig fixture definition."
             )
-            raise errors.SetupError('no kube config defined for test run')
+            raise errors.SetupError("no kube config defined for test run")
 
     test_case = manager.get_test(request.node.nodeid)
     if test_case is None:
         log.error(
             f'No kubetest client found for test using the "kube" fixture. ({request.node.nodeid})',  # noqa
         )
-        raise errors.SetupError('error generating test client')
+        raise errors.SetupError("error generating test client")
 
     # Setup the test case. This will create the namespace and any other
     # objects (e.g. role bindings) that the test case will need.
